@@ -20,19 +20,20 @@ use warnings;
 
 =pod
 
-=head2 log($message)
+=head2 log($message, $severity)
 
-	$h->log($message);
+	$h->log('Just testing', 'info');
 
-Logs the provided string to STDERR.
+Logs the provided string to STDERR with a prefixed severity.
 
 =cut
 
 ###########################################################
 sub log{	#a simple way to log a message to the apache error log
-	my($self, $message) = @_;
-	print STDERR $message . "\n";
-	return 1;
+	my($self, $message, $severity) = @_;
+	$severity = "" unless $severity;
+	return if !$self->getOption('debug') and $severity eq 'debug';	#ignore debug messages when not in debug mode
+	print STDERR uc($severity) . " - " . $message . "\n";
 }
 #################################################
 
