@@ -29,7 +29,7 @@ The module L<PSGI::Hector::Response> will load the specified response plugin on
 
 use strict;
 use warnings;
-use parent qw(HTTP::Response PSGI::Hector::Base PSGI::Hector::Log);
+use parent qw(HTTP::Response PSGI::Hector::Base);
 #########################################################
 sub new{
 	my($class, $hector) = @_;
